==> ocstore25_6_20.zip: OcStore/Prgm/data/language/en-us/script/CS_santa_house.lua <==
function E0090()
    SetColonAction()
    MNA()FAI(0)
end
function E0091()
    SetColonAction()
    MNA()FAI(1)
end
function E0092()
    SetColonAction()
    MNA()FAI(2)
end
function E0093()
    SetColonAction()
    MNA()FAI(3)
end
function E0094()
    SetColonAction()
    MNA()FAI(4)
end

--设置科恩动作
function SetColonAction()
    if(FLJ("KingBack")) then
        MNP("Colon4",18,19,1)
        MNP("Colon3",19,19,1)
        MNP("Colon2",21,19,1)
        MNP("Colon1",22,19,1)
        ANP("Colon4","sit",1)
        ANP("Colon3","sit",0)
        ANP("Colon2","sleep",1)
        ANP("Colon1","sleep",1)
        DNP("Fireplace1")
        CMU("CS_Kodou")
    else
        ANP("Colon1","sit")--坐着的
        ANP("Colon2","sit")--坐着的
        ANP("Colon3","sit")--坐着的
        ANP("Colon4","sit")--坐着的
        CMU("CS_Anzen")
    end
end

--去外面
function Door_GoVillage()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoVillage",0,1)FAO(2)TRA("CS_village","E0090",14,15)
end

--科恩1
function Colon1()
    KEY()MS3("Because monsters appeared,")NOD()
    CAT("\nChako protected us by")
    CAT("\nbringing us all back here.")NOD()
    if(FLJ("Colon1GiveExp")) then
        SNP("CS_exp_placer",20,12,0,"mainLayer","ExpPlacer1")
        ANP("ExpPlacer1",9)
        FLS("Colon1GiveExp")
    end
end

function Colon2()
    KEY()MS3("I really miss Curly")NOD()
    CAT("\nI hope she comes back soon.")NOD()
    if(FLJ("Colon2GiveExp")) then
        SNP("CS_exp_placer",21,12,0,"mainLayer","ExpPlacer2")
        ANP("ExpPlacer2",9)
        FLS("Colon2GiveExp")
    end
end

function Colon3()
    KEY()MS3("Is that a real gun?")NOD()
    CAT("\nYou guys fighting monsters together") 
    CAT("\nis so cool!")NOD()
    if(FLJ("Colon3GiveExp")) then
        SNP("CS_exp_placer",22,12,0,"mainLayer","ExpPlacer3")
        ANP("ExpPlacer3",9)
        FLS("Colon3GiveExp")
    end
end

function Colon4()
    KEY()MS3("I hope Sue and Toroko")
    CAT("\nare both safe and sound.")NOD()
    if(FLJ("Colon4GiveExp")) then
        SNP("CS_exp_placer",23,12,0,"mainLayer","ExpPlacer4")
        ANP("ExpPlacer4",9)
        FLS("Colon4GiveExp")
    end
end

function Chako1()
    KEY()FAC("chako_happy")MS3("There's a basement where the") 
    CAT("\nchildren can hide safely,")NOD()
    CAT("\nso you can go with peace of mind.")NOD()CLR()
    if(ITJ("TorokoNecklace")) then
        GIT("TorokoNecklace")
        FAC("chako_normal")CAT("That's Toroko's necklace,")NOD()
        CAT("\nmaybe you can use it to") 
        CAT("\nfind where they are.")NOD()
    end
    if(FLJ("ChakoGiveExp")) then
        SNP("CS_exp_placer",25,12,0,"mainLayer","ExpPlacer5")
        ANP("ExpPlacer5",29)
        FLS("ChakoGiveExp")
    end
end

function HideInBasement()
    KEY()
    MNP("Chako1",18,14,1)
    ANP("Chako1","back",1)
    ANP("Colon1","normal",0)
    ANP("Colon2","normal",0)
    ANP("Colon3","normal",0)
    ANP("Colon4","normal",0)
    DNP("Fireplace1")
    FAI(0)
    FAC("chako_normal")MS3("Monsters are coming!")NOD()
    CAT("\nEveryone, quickly hide")
    CAT("\nin the basement.")NOD()CLO()
    ANP("Colon4","walk",1)
    WAI(16)
    ANP("Colon4","back",1)
    ANP("Colon3","walk",1)
    WAI(16)
    ANP("Colon2","walk",1)
    MNP("Colon4",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon4","normal",0)
    WAI(15)
    ANP("Colon1","walk",1)
    ANP("Colon3","back",1)
    ANP("Colon4","walk",0)
    WAI(16)
    MNP("Colon3",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon3","normal",0)
    WAI(15)
    ANP("Colon2","back",1)
    ANP("Colon3","walk",0)
    WAI(16)
    MNP("Colon2",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon2","normal",0)
    WAI(14)
    ANP("Colon1","back",1)
    ANP("Colon2","walk",0)
    WAI(16)
    MNP("Colon1",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon1","normal",0)
    WAI(16)
    ANP("Chako1","walk",1)
    ANP("Colon1","walk",0)
    WAI(16)
    ANP("Colon4","normal",1)
    WAI(16)
    ANP("Colon3","normal",1)
    WAI(16)
    ANP("Colon2","normal",1)
    WAI(16)
    ANP("Colon1","normal",1)
    WAI(27)
    ANP("Chako1","back",1)
    WAI(16)
    MNP("Chako1",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Chako1","normal",0)
    WAI(16)
    ANP("Chako1","walk",0)
    WAI(32)
    ANP("Chako1","normal",0)
    WAI(32)
    FAC("chako_normal")MS3("Everyone stay quiet,")NOD()
    CAT("\njust hide here silently,")NOD()
    CAT("\nthe monsters will never find us.")NOD()CLR()
    FAC()CAT("\nUnderstood.")NOD()CLO()
    WAI(32)
    PMU(1)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    WAI(32)
    SNP("CS_soapwalker_animate",18,14,1,"mainLayer","SoapWalker1")
    ANP("SoapWalker1","look_down",1)
    WAI(32)
    FAC("soapwalker_normal")MS3("\nWhere are my little darlings?")NOD()CLO()
    ANP("SoapWalker1","walk",1)
    WAI(96)
    ANP("SoapWalker1","walk",0)
    WAI(96)
    WAI(8)
    ANP("SoapWalker1","normal",0)
    ANP("SoapWalker1","look_normal",0)
    WAI(16)
    ANP("SoapWalker1","jump",0)
    WAI(64)
    ANP("SoapWalker1","normal",1)
    WAI(16)
    ANP("SoapWalker1","big_jump",1)
    WAI(64)
    MS3("Strange, nobody's here today,")NOD()
    CAT("\nI'll check somewhere else.")CLO()
    WAI(32)
    ANP("SoapWalker1","walk",1)
    WAI(8)
    ANP("SoapWalker1","normal",1)
    WAI(32)
    DNP("SoapWalker1")
    WAI(32)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    WAI(32)
    RMU()
    FAO(2)TRA("CS_king_house","PuuSearch",14,15)
end

function ChakoObserve()
    KEY()
    MNP("Colon4",18,19,1)
    MNP("Colon3",19,19,1)
    MNP("Colon2",21,19,1)
    MNP("Colon1",22,19,1)
    MNP("Chako1",18,14,1)
    ANP("Chako1","back",1)
    DNP("Fireplace1")
    FAI(0)
    QUA(30)
    SOU("CS_026_quake")
    WAI(64)
    FAC("chako_normal")MS3("It seems the monster has left,")NOD()
    CAT("\nbut I heard something unbelievable.")NOD()CLR()
    ANP("Chako1","normal",1)
    CAT("If that's the case,") 
    CAT("\nToroko and the others")
    CAT("\nshould still be safe.")NOD()CLR()
    CAT("Three of them,")NOD()
    CAT("\nso the other one must be Kanpachi.")NOD()CLO()
    ANP("Chako1","walk",1)
    WAI(96)
    ANP("Chako1","normal",1)
    WAI(16)
    ANP("Chako1","back",1)
    WAI(16)
    FAC("chako_happy")MS3("Children, Sue and the others")
    CAT("\nare safe for now,")NOD()
    CAT("\nthey're just being held somewhere.")NOD()CLR()
    CAT("But until the monsters are defeated,")NOD()
    CAT("\nwe need to stay here for a few days.")NOD()CLR()
    FAC()CAT("\nUnderstood~")NOD()CLO()
    WAI(32)
    ANP("Chako1","normal",0)
    WAI(32)
    FAC("chako_happy")MS3("I'll go to the assembly hall")
    CAT("\nto get food for these days,")NOD()
    CAT("\ndon't come out until I return, okay?")NOD()CLR()
    FAC()CAT("\nYes, Sister Chako.")NOD()CLO()
    WAI(16)
    ANP("Chako1","walk",0)
    WAI(96)
    ANP("Chako1","normal",0)
    WAI(16)
    ANP("Chako1","back",0)
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    WAI(16)
    DNP("Chako1")
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    WAI(16)
    FAO(2)TRA("CS_village","ChakoGoKingHouseGetFood",0,0)
end

function KingBack()
    KEY()
    AMC("normal",1)
    MNP("Colon4",18,19,1)
    MNP("Colon3",19,19,1)
    MNP("Colon2",21,19,1)
    MNP("Colon1",22,19,1)
    ANP("Colon4","sit",1)
    ANP("Colon3","sit",0)
    ANP("Colon2","sleep",1)
    ANP("Colon1","sleep",1)
    HMC(0)
    FAI(2)
    WAI(32)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    WAI(16)
    SMC(0)
    WAI(32)
    FAC("king_normal")MS3("Santa! Chako!?")NOD()
    CAT("\nAre you here?")NOD()CLO()
    WAI(32)
    AMC("back")
    WAI(32)
    HMC(0)
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    WAI(32)
    SNP("CS_exclamation",18,18,0,"mainLayer","null")--感叹号
    WAI(32)
    ANP("Colon4","normal")
    WAI(32)
    ANP("Colon3","normal")
    WAI(32)
    MS3("That sounds like Chief King!")NOD()
    CAT("\nKing is back!")NOD()CLO()
    WAI(16)
    FAO(0)
    TRA("CS_bar2","KingBack",28,14)
end

function KingAndColon()
    KEY()
    AMC("normal",0)
    CMU("CS_Kodou")
    FAI(2)
    WAI(32)
    FAC("king_normal")MS3("\nI see, so that's what happened.")NOD()CLR()
    CAT("I understand,")NOD()
    CAT("\nI'll definitely rescue everyone!")NOD()CLR()
    CAT("You all keep hiding in this house,")NOD()
    CAT("\nI'll be back soon.")NOD()CLO()
    WAI(32)
    FAO(0)
    TRA("CS_king_house","KingReadyToGo",16,15)
end

==> ocstore25_8_11.zip: OcStore/Prgm/data/language/en-us/script/CS_santa_house.lua <==
function E0090()
    SetColonAction()
    MNA()FAI(0)
end
function E0091()
    SetColonAction()
    MNA()FAI(1)
end
function E0092()
    SetColonAction()
    MNA()FAI(2)
end
function E0093()
    SetColonAction()
    MNA()FAI(3)
end
function E0094()
    SetColonAction()
    MNA()FAI(4)
end

--设置科恩动作
function SetColonAction()
    if(FLJ("KingBack")) then
        MNP("Colon4",18,19,1)
        MNP("Colon3",19,19,1)
        MNP("Colon2",21,19,1)
        MNP("Colon1",22,19,1)
        ANP("Colon4","sit",1)
        ANP("Colon3","sit",0)
        ANP("Colon2","sleep",1)
        ANP("Colon1","sleep",1)
        DNP("Fireplace1")
        CMU("CS_Kodou")
    else
        ANP("Colon1","sit")--坐着的
        ANP("Colon2","sit")--坐着的
        ANP("Colon3","sit")--坐着的
        ANP("Colon4","sit")--坐着的
        CMU("CS_Anzen")
    end
end

--去外面
function Door_GoVillage()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoVillage",0,1)FAO(2)TRA("CS_village","E0090",14,15)
end

--科恩1
function Colon1()
    KEY()MS3("Because monsters appeared,")NOD()
    CAT("\nChako protected us by")
    CAT("\nbringing us all back here.")NOD()
    if(FLJ("Colon1GiveExp")) then
        SNP("CS_exp_placer",20,12,0,"mainLayer","ExpPlacer1")
        ANP("ExpPlacer1",9)
        FLS("Colon1GiveExp")
    end
end

function Colon2()
    KEY()MS3("I really miss Curly")NOD()
    CAT("\nI hope she comes back soon.")NOD()
    if(FLJ("Colon2GiveExp")) then
        SNP("CS_exp_placer",21,12,0,"mainLayer","ExpPlacer2")
        ANP("ExpPlacer2",9)
        FLS("Colon2GiveExp")
    end
end

function Colon3()
    KEY()MS3("Is that a real gun?")NOD()
    CAT("\nYou guys fighting monsters together") 
    CAT("\nis so cool!")NOD()
    if(FLJ("Colon3GiveExp")) then
        SNP("CS_exp_placer",22,12,0,"mainLayer","ExpPlacer3")
        ANP("ExpPlacer3",9)
        FLS("Colon3GiveExp")
    end
end

function Colon4()
    KEY()MS3("I hope Sue and Toroko")
    CAT("\nare both safe and sound.")NOD()
    if(FLJ("Colon4GiveExp")) then
        SNP("CS_exp_placer",23,12,0,"mainLayer","ExpPlacer4")
        ANP("ExpPlacer4",9)
        FLS("Colon4GiveExp")
    end
end

function Chako1()
    KEY()FAC("chako_happy")MS3("There's a basement where the") 
    CAT("\nchildren can hide safely,")NOD()
    CAT("\nso you can go with peace of mind.")NOD()CLR()
    if(ITJ("TorokoNecklace")) then
        GIT("TorokoNecklace")
        FAC("chako_normal")CAT("That's Toroko's necklace,")NOD()
        CAT("\nmaybe you can use it to") 
        CAT("\nfind where they are.")NOD()
    end
    if(FLJ("ChakoGiveExp")) then
        SNP("CS_exp_placer",25,12,0,"mainLayer","ExpPlacer5")
        ANP("ExpPlacer5",29)
        FLS("ChakoGiveExp")
    end
end

function HideInBasement()
    KEY()
    MNP("Chako1",18,14,1)
    ANP("Chako1","back",1)
    ANP("Colon1","normal",0)
    ANP("Colon2","normal",0)
    ANP("Colon3","normal",0)
    ANP("Colon4","normal",0)
    DNP("Fireplace1")
    FAI(0)
    FAC("chako_normal")MS3("Monsters are coming!")NOD()
    CAT("\nEveryone, quickly hide")
    CAT("\nin the basement.")NOD()CLO()
    ANP("Colon4","walk",1)
    WAI(16)
    ANP("Colon4","back",1)
    ANP("Colon3","walk",1)
    WAI(16)
    ANP("Colon2","walk",1)
    MNP("Colon4",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon4","normal",0)
    WAI(15)
    ANP("Colon1","walk",1)
    ANP("Colon3","back",1)
    ANP("Colon4","walk",0)
    WAI(16)
    MNP("Colon3",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon3","normal",0)
    WAI(15)
    ANP("Colon2","back",1)
    ANP("Colon3","walk",0)
    WAI(16)
    MNP("Colon2",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon2","normal",0)
    WAI(14)
    ANP("Colon1","back",1)
    ANP("Colon2","walk",0)
    WAI(16)
    MNP("Colon1",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon1","normal",0)
    WAI(16)
    ANP("Chako1","walk",1)
    ANP("Colon1","walk",0)
    WAI(16)
    ANP("Colon4","normal",1)
    WAI(16)
    ANP("Colon3","normal",1)
    WAI(16)
    ANP("Colon2","normal",1)
    WAI(16)
    ANP("Colon1","normal",1)
    WAI(27)
    ANP("Chako1","back",1)
    WAI(16)
    MNP("Chako1",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Chako1","normal",0)
    WAI(16)
    ANP("Chako1","walk",0)
    WAI(32)
    ANP("Chako1","normal",0)
    WAI(32)
    FAC("chako_normal")MS3("Everyone stay quiet,")NOD()
    CAT("\njust hide here silently,")NOD()
    CAT("\nthe monsters will never find us.")NOD()CLR()
    FAC()CAT("\nUnderstood.")NOD()CLO()
    WAI(32)
    PMU(1)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    WAI(32)
    SNP("CS_soapwalker_animate",18,14,1,"mainLayer","SoapWalker1")
    ANP("SoapWalker1","look_down",1)
    WAI(32)
    FAC("soapwalker_normal")MS3("\nWhere are my little darlings?")NOD()CLO()
    ANP("SoapWalker1","walk",1)
    WAI(96)
    ANP("SoapWalker1","walk",0)
    WAI(96)
    WAI(8)
    ANP("SoapWalker1","normal",0)
    ANP("SoapWalker1","look_normal",0)
    WAI(16)
    ANP("SoapWalker1","jump",0)
    WAI(64)
    ANP("SoapWalker1","normal",1)
    WAI(16)
    ANP("SoapWalker1","big_jump",1)
    WAI(64)
    MS3("Strange, nobody's here today,")NOD()
    CAT("\nI'll check somewhere else.")CLO()
    WAI(32)
    ANP("SoapWalker1","walk",1)
    WAI(8)
    ANP("SoapWalker1","normal",1)
    WAI(32)
    DNP("SoapWalker1")
    WAI(32)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    WAI(32)
    RMU()
    FAO(2)TRA("CS_king_house","PuuSearch",14,15)
end

function ChakoObserve()
    KEY()
    MNP("Colon4",18,19,1)
    MNP("Colon3",19,19,1)
    MNP("Colon2",21,19,1)
    MNP("Colon1",22,19,1)
    MNP("Chako1",18,14,1)
    ANP("Chako1","back",1)
    DNP("Fireplace1")
    FAI(0)
    QUA(30)
    SOU("CS_026_quake")
    WAI(64)
    FAC("chako_normal")MS3("It seems the monster has left,")NOD()
    CAT("\nbut I heard something unbelievable.")NOD()CLR()
    ANP("Chako1","normal",1)
    CAT("If that's the case,") 
    CAT("\nToroko and the others")
    CAT("\nshould still be safe.")NOD()CLR()
    CAT("Three of them,")NOD()
    CAT("\nso the other one must be Kanpachi.")NOD()CLO()
    ANP("Chako1","walk",1)
    WAI(96)
    ANP("Chako1","normal",1)
    WAI(16)
    ANP("Chako1","back",1)
    WAI(16)
    FAC("chako_happy")MS3("Children, Sue and the others")
    CAT("\nare safe for now,")NOD()
    CAT("\nthey're just being held somewhere.")NOD()CLR()
    CAT("But until the monsters are defeated,")NOD()
    CAT("\nwe need to stay here for a few days.")NOD()CLR()
    FAC()CAT("\nUnderstood~")NOD()CLO()
    WAI(32)
    ANP("Chako1","normal",0)
    WAI(32)
    FAC("chako_happy")MS3("I'll go to the assembly hall")
    CAT("\nto get food for these days,")NOD()
    CAT("\ndon't come out until I return, okay?")NOD()CLR()
    FAC()CAT("\nYes, Sister Chako.")NOD()CLO()
    WAI(16)
    ANP("Chako1","walk",0)
    WAI(96)
    ANP("Chako1","normal",0)
    WAI(16)
    ANP("Chako1","back",0)
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    WAI(16)
    DNP("Chako1")
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    WAI(16)
    FAO(2)TRA("CS_village","ChakoGoKingHouseGetFood",0,0)
end

function KingBack()
    KEY()
    AMC("normal",1)
    MNP("Colon4",18,19,1)
    MNP("Colon3",19,19,1)
    MNP("Colon2",21,19,1)
    MNP("Colon1",22,19,1)
    ANP("Colon4","sit",1)
    ANP("Colon3","sit",0)
    ANP("Colon2","sleep",1)
    ANP("Colon1","sleep",1)
    HMC(0)
    FAI(2)
    WAI(32)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    WAI(16)
    SMC(0)
    WAI(32)
    FAC("king_normal")MS3("Santa! Chako!?")NOD()
    CAT("\nAre you here?")NOD()CLO()
    WAI(32)
    AMC("back")
    WAI(32)
    HMC(0)
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    WAI(32)
    SNP("CS_exclamation",18,18,0,"mainLayer","null")--感叹号
    WAI(32)
    ANP("Colon4","normal")
    WAI(32)
    ANP("Colon3","normal")
    WAI(32)
    MS3("That sounds like Chief King!")NOD()
    CAT("\nKing is back!")NOD()CLO()
    WAI(16)
    FAO(0)
    TRA("CS_bar2","KingBack",28,14)
end

function KingAndColon()
    KEY()
    AMC("normal",0)
    CMU("CS_Kodou")
    FAI(2)
    WAI(32)
    FAC("king_normal")MS3("\nI see, so that's what happened.")NOD()CLR()
    CAT("I understand,")NOD()
    CAT("\nI'll definitely rescue everyone!")NOD()CLR()
    CAT("You all keep hiding in this house,")NOD()
    CAT("\nI'll be back soon.")NOD()CLO()
    WAI(32)
    FAO(0)
    TRA("CS_king_house","KingReadyToGo",16,15)
end

--生命胶囊（普通）
function PathLifeCapsule1_Normal()
    PRI()SOU("CS_022_chest_open")CMU("CS_Fanfale2")DNP("PathLifeCapsule1_Normal")FLP("PathLifeCapsule1_Normal")
    MS4("Got a =LIFE CAPSULE=!")WAI(160)NOD()RMU()
    MLP(5)
    CAT("\nMax health increased by 5!")NOD()
end
